![lawu](lawu.png)

# lawu

[![license](https://img.shields.io/github/license/tktech/lawu.svg?style=for-the-badge)](LICENCE)

Lawu is a human-friendly library for assembling, disassembling, and exploring
JVM class files. It's highly suitable for automation tasks.

## Documentation

API documentation & examples are available at http://lawu.tkte.ch

## Licence

Lawu is available under the MIT licence. See LICENCE.
